---
title: Не работает VPN по настройкам ovpn в линукс
slug: администрирование-vpn/не-работает-vpn-по-настройкам-ovpn-в-линукс
---

После подключения к VPN через `.ovpn`-файл на Fedora может наблюдаться ситуация:
**ping работает**, а **сайты в браузере не открываются**. Это связано с проблемами MTU (размер максимального пакета).

---

## ✅ Симптомы

* `ping google.com` работает
* сайты в браузере не открываются
* в Windows с тем же `.ovpn` всё работает нормально

---

## 🛍️ Причина

VPN-интерфейс `tun0` устанавливает `MTU = 1500`, что слишком много для некоторых провайдеров/сетей.
Фрагментация запрещается, и крупные пакеты (например, HTTPS) отбрасываются.

---

## 🧪 Диагностика MTU

Определи максимальный размер пакета без фрагментации:

```bash
ping -M do -s 1272 8.8.8.8
```

Уменьшай `-s`, пока пинг не начнёт работать. Затем:

```bash
tun-mtu = <s> + 28
```

---

## 🔧 Решение

1. Открой `.ovpn`-файл в текстовом редакторе:

```bash
nano your_config.ovpn
```

2. Добавь в конец файла строки:

```
tun-mtu 1300
mssfix 1200
```

*(Если по `ping` удалось пройти с `-s 1372`, можно поставить `tun-mtu 1400`, `mssfix 1360`)*

3. Сохрани файл и переподключись:

```bash
sudo openvpn --config your_config.ovpn
```

---

## ✅ Результат

* VPN работает
* Сайты загружаются в браузере
* Проблем с DNS и HTTPS больше нет

---

## 📝 Примечание

Альтернативно можно временно задать параметры через команду запуска:

```bash
sudo openvpn --config your_config.ovpn --tun-mtu 1300 --mssfix 1200
```

Но при следующем запуске без этих флагов проблема вернётся, если не внести изменения в `.ovpn`.

---
