---
title: Представление контактной информации объекта
slug: общие-бсп-стандартные-подсистемы-контактная-информация-программный-интерфейс/представление-контактной-информации-объекта
---
# Описание

```bsl

// Возвращает представление контактной информации объекта.
//
// Параметры:
//  СсылкаИлиОбъект         - Произвольный - владелец контактной информации.
//  ВидКонтактнойИнформации - СправочникСсылка.ВидыКонтактнойИнформации - вид контактной информации.
//  Разделитель             - Строка - разделитель, который добавляется в представление между записями контактной информации.
//                                     По умолчанию это запятая с последующим пробелом, для исключения
//                                     пробела необходимо использовать признак БезПробелов у параметра ДополнительныеПараметры.
//  Дата                    - Дата - дата, с которой действует запись контактной информации. Если контактная информация
//                                   хранит историю изменения, то передача даты обязательна.
//  ДополнительныеПараметры - Структура - необязательные параметры для формирования представления контактной информации:
//   * ТолькоПервая         - Булево - если Истина, то будет возвращено представление только основной(первой) записи
//                                     контактной информации. По умолчанию - Ложь;
//   * БезПробелов          - Булево - если Истина, то после разделителя не будет автоматически добавляться пробел.
//                                     По умолчанию - Ложь;
// 
// Возвращаемое значение:
//  Строка
//
Функция ПредставлениеКонтактнойИнформацииОбъекта(СсылкаИлиОбъект, ВидКонтактнойИнформации, Разделитель = ",", Дата = Неопределено, ДополнительныеПараметры = Неопределено) Экспорт

```

# Пример применения

```bsl

Организация = Справочники.Организации.ОрганизацияПоУмолчанию();
ВидЮрАдрес = Справочники.ВидыКонтактнойИнформации.ЮрАдресОрганизации;
ВидEmail = Справочники.ВидыКонтактнойИнформации.EmailОрганизации;

ЮрАдрес = УправлениеКонтактнойИнформацией.ПредставлениеКонтактнойИнформацииОбъекта(Организация, ВидЮрАдрес);
Email = УправлениеКонтактнойИнформацией.ПредставлениеКонтактнойИнформацииОбъекта(Организация, ВидEmail);

ОбщегоНазначения.СообщитьПользователю(СтрШаблон("Юр. адрес: %1; Email: %2", ЮрАдрес, Email));

```