---
title: Записать свойства у объекта
slug: общие-бсп-стандартные-подсистемы-свойства-программный-интерфейс/записать-свойства-у-объекта
---
# Описание

```bsl
// Записывает дополнительные реквизиты и сведения владельцу свойств.
// Изменения происходят в транзакции.
// Синтаксис
//
// Процедура ЗаписатьСвойстваУОбъекта(ВладелецСвойств, ТаблицаСвойствИЗначений) Экспорт
//
// Параметры
//
//  ВладелецСвойств - ЛюбаяСсылка - например, СправочникСсылка.Номенклатура, ДокументСсылка.ЗаказПокупателя и т.д.
//  ТаблицаСвойствИЗначений - ТаблицаЗначений:
//    * Свойство - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения - свойство владельца.
//    * Значение - Произвольный - любое значение, допустимое для свойства (указано в элементе свойства).
УправлениеСвойствами.ЗаписатьСвойстваУОбъекта(ВладелецСвойств, ТаблицаСвойств);
```

# Пример применения
```bsl
Номенклатура = Справочники.Номенклатура.НайтиПоКоду("000000001");
Если НЕ Номенклатура.Пустая() Тогда
	
	ТаблицаСвойств = Новый ТаблицаЗначений();
	ТаблицаСвойств.Колонки.Добавить("Свойство");
	ТаблицаСвойств.Колонки.Добавить("Значение");
	
	ИмяСвойстваБеспроводной = "БеспроводнойИнтерфейс_1f84313ad678448db40fa1c403f26aba";
	
	СтрокаТаблицы = ТаблицаСвойств.Добавить();
	СтрокаТаблицы.Свойство = ПланыВидовХарактеристик.ДополнительныеРеквизитыИСведения.НайтиПоРеквизиту("Имя", ИмяСвойстваБеспроводной);
	СтрокаТаблицы.Значение = Истина;
	
	ИмяСвойстваШумоподавление = "АктивноеШумоподавление_d6d55617cc4746ff801c790c2ff8ca07";
	
	СтрокаТаблицы = ТаблицаСвойств.Добавить();
	СтрокаТаблицы.Свойство = ПланыВидовХарактеристик.ДополнительныеРеквизитыИСведения.НайтиПоРеквизиту("Имя", ИмяСвойстваШумоподавление);
	СтрокаТаблицы.Значение = Истина;

	УправлениеСвойствами.ЗаписатьСвойстваУОбъекта(Номенклатура, ТаблицаСвойств);
	
	ОбщегоНазначения.СообщитьПользователю("Свойства номенклатуры успешно записаны");	
	
Иначе
	ОбщегоНазначения.СообщитьПользователю("Номенклатура не найдена");	
КонецЕсли;
```