---
title: Значение свойства
slug: общие-бсп-стандартные-подсистемы-свойства-программный-интерфейс/значение-свойства
---

# Описание

```bsl
// Возвращает значение дополнительного свойства объекта.
// Синтаксис
//
// Функция ЗначениеСвойства(Объект, Свойство, КодЯзыка = "") Экспорт
//
// Параметры:
//
//  Объект   - ЛюбаяСсылка - ссылка на объект, например, СправочникСсылка.Номенклатура,
//                           ДокументСсылка.ЗаказПокупателя, ...
//  Свойство - ПланВидовХарактеристикСсылка.ДополнительныеРеквизитыИСведения - ссылка на
//                           дополнительный реквизит, значение которого нужно получить.
//           - Строка - имя дополнительного свойства.
//  КодЯзыка - Строка - если указано, то вместо значения дополнительного свойства будет
//                      возвращено его представление на указанном языке.
//Возвращаемое значение
//
//  Произвольный - любое значение, допустимое для свойства.
Значение = УправлениеСвойствами.ЗначениеСвойства(Объект, ИмяСвойства);
```

# Пример применения
```bsl
Номенклатура = Справочники.Номенклатура.НайтиПоКоду("000000001");
Если НЕ Номенклатура.Пустая() Тогда

	// вариант 1 - по имени свойства
	ИмяСвойства = "ОперационнаяСистема_ce01ea8bc2c34f4bad6f81092280c579";
	Значение = УправлениеСвойствами.ЗначениеСвойства(Номенклатура, ИмяСвойства);
	
	// вариант 2 - по ссылке на свойство
	Свойство = ПланыВидовХарактеристик.ДополнительныеРеквизитыИСведения.НайтиПоРеквизиту("Имя", ИмяСвойства);
	Значение = УправлениеСвойствами.ЗначениеСвойства(Номенклатура, Свойство);
	
	ОбщегоНазначения.СообщитьПользователю(Значение);
	
Иначе
	ОбщегоНазначения.СообщитьПользователю("Номенклатура не найдена");	
КонецЕсли;
```