---
title: Добавить файлы
slug: общие-бсп-стандартные-подсистемы-файлы-программный-интерфейс-клиент/добавить-файлы
---

# Описание

```bsl
// Открывает диалог выбора файлов для помещения в программу одного или нескольких файлов.
// При этом проверяются необходимые условия:
// - размер файла не превышает максимально допустимого,
// - файл имеет допустимое расширение,
// - имеется свободное место в томе (при хранении файлов в томах),
// - прочие условия.
// Синтаксис
//
// Процедура ДобавитьФайлы(Знач ВладелецФайла, Знач ИдентификаторФормы, Знач Фильтр = "", ГруппаФайлов = Неопределено,
//	ОбработчикРезультата = Неопределено) Экспорт
// Параметры
//
//  ВладелецФайла      - ОпределяемыйТип.ВладелецПрисоединенныхФайлов - папка файлов или объект, к которому
//                       требуется прикрепить добавляемый файл.
//  ИдентификаторФормы - УникальныйИдентификатор - уникальный идентификатор формы, во временное хранилище
//                       которой будет помещен файл.
//  Фильтр             - Строка - фильтр выбираемого файла, например, картинки для номенклатуры.
//  ГруппаФайлов       - ОпределяемыйТип.ПрисоединенныйФайл - группа справочника с файлами, в которую будет 
//                       добавлен новый файл.
//  ОбработчикРезультата - ОписаниеОповещения - описание процедуры, вызов которой будет произведен
//                         после добавления файлов со следующими параметрами:
//        Результат - Массив - ссылки на добавленные файлы. Если файлы не были добавлены, пустой массив.
//        ДополнительныеПараметры - Произвольный - значение, указанное при создании описания оповещения.
РаботаСФайламиКлиент.ДобавитьФайлы(Объект.Номенклатура, ЭтотОбъект.УникальныйИдентификатор,,,Оповещение);	
```

# Пример применения
```bsl
&НаКлиенте
Процедура ДобавитьФайлы(Команда)
	
	Оповещение = Новый ОписаниеОповещения("ДобавитьФайлыЗавершение", ЭтотОбъект);
	РаботаСФайламиКлиент.ДобавитьФайлы(Объект.Номенклатура, ЭтотОбъект.УникальныйИдентификатор,,,Оповещение);	
	
КонецПроцедуры

&НаКлиенте
Процедура ДобавитьФайлыЗавершение(Результат, ДополнительныеПараметры) Экспорт
	
	Если Результат = Неопределено Тогда
		Возврат;
	КонецЕсли;
	
	Если Результат.Количество() = 0 Тогда
		ОбщегоНазначенияКлиент.СообщитьПользователю("Не удалось добавить файлы...");		
		Возврат;
	КонецЕсли;   

	ОбщегоНазначенияКлиент.СообщитьПользователю(СтрШаблон("Добавлено %1 файлов", Результат.Количество()));

КонецПроцедуры // ДобавитьФайлЗавершение()

```