---
title: Записать в журнал регистрации (клиент)
slug: общие-исключения-обработка-ошибок/записать-в-журнал-регистрации-клиент
---

# Шаг 1 - накапливаем сообщения
```bsl
// Записывает сообщение в журнал регистрации.
// Если параметр ЗаписатьСобытия = Истина, то запись выполняется сразу (обращение к серверу).
// Если ЗаписатьСобытия = Ложь (по умолчанию), то сообщение помещается в очередь, которая
// будет записана позднее (обычно в течение 60 сек), либо при следующем вызове этой процедуры
// с признаком ЗаписатьСобытия = Истина, либо при вызове процедуры ЗаписатьСобытияВЖурналРегистрации.
//
//  Параметры: 
//   ИмяСобытия          - Строка - имя события для журнала регистрации;
//   ПредставлениеУровня - Строка - описание уровня события, по нему будет определен уровень события при записи на
//                                  сервере;
//                                  Например: "Ошибка", "Предупреждение".
//                                  Соответствуют именам элементов перечисления УровеньЖурналаРегистрации.
//   Комментарий         - Строка - комментарий для события журнала;
//   ДатаСобытия         - Дата   - точная дата возникновения события, описанного в сообщении. Будет добавлена в начало
//                                  комментария;
//   ЗаписатьСобытия     - Булево - выполнить запись всех ранее накопленных сообщений в журнал регистрации (обращение к
//                                  серверу).
//
// Пример:
//  ЖурналРегистрацииКлиент.ДобавитьСообщениеДляЖурналаРегистрации(СобытиеЖурналаРегистрации(), "Предупреждение",
//     НСтр("ru = 'Невозможно подключиться к сети Интернет для проверки обновлений.'"));
//
ЖурналРегистрацииКлиент.ДобавитьСообщениеДляЖурналаРегистрации(Знач ИмяСобытия, Знач ПредставлениеУровня = "Информация", 
	Знач Комментарий = "", Знач ДатаСобытия = "", Знач ЗаписатьСобытия = Ложь) Экспорт
	
```

# Шаг 2 - вызов сервера для записи в журнал регистрации
```bsl

// Записывает накопленные сообщения из очереди в журнал регистрации (обращение к серверу).
// Сообщения добавляются в очередь с помощью процедуры ДобавитьСообщениеДляЖурналаРегистрации.
//
ЖурналРегистрацииКлиент.ЗаписатьСобытияВЖурналРегистрации() Экспорт


```