---
title: Загрузить файл во временное хранилище
slug: общие-работа-с-файловой-системой/загрузить-файл-во-временное-хранилище
---
# Описание

```bsl

// Показывает диалог выбора файла и помещает выбранный файл во временное хранилище.
// Совмещает работу методов глобального контекста НачатьПомещениеФайла и НачатьПомещениеФайлов,
// возвращая идентичный результат вне зависимости от того, подключено или нет расширение для работы с 1С:Предприятием.
// Ограничения:
//   Не используется для выбора каталогов - эта опция не поддерживается веб-клиентом.
//
// Параметры:
//   ОбработчикЗавершения - ОписаниеОповещения - содержит описание процедуры, которая будет вызвана после
//                                               загрузки файла со следующими параметрами:
//      # ПомещенныйФайл  - Структура    - пользователь выбрал файл:
//                           ## Хранение  - Строка - адрес временного хранилища с двоичными данными файла.
//                           ## Имя       - Строка - в тонком клиенте и в веб-клиенте с установленным
//                                        расширением работы с 1С:Предприятием - локальный путь, по которому
//                                        был получен файл. В веб-клиенте без расширения для работы с 1С:Предприятием
//                                        передается имя файла с расширением.
//                        - Неопределено - пользователь отказался от выбора или файл занят другой программой.
//      # ДополнительныеПараметры - Произвольный - значение, которое было указано при создании объекта
//                                                 ОписаниеОповещения.
//   ПараметрыЗагрузки         - см. ФайловаяСистемаКлиент.ПараметрыЗагрузкиФайла.
//   ИмяФайла                  - Строка - полный путь к файлу, который будет предложен пользователю в начале
//                             интерактивного выбора или помещен во временное хранилище в неинтерактивном. 
//                             Если выбран неинтерактивный режим и параметр не заполнен, будет вызвано исключение.
//   АдресВоВременномХранилище - Строка - адрес, по которому будет сохранен файл.
//
// Пример:
//   Оповещение = Новый ОписаниеОповещения("ВыбратьФайлПослеПомещенияФайла", ЭтотОбъект, Контекст);
//   ПараметрыЗагрузки = ФайловаяСистемаКлиент.ПараметрыЗагрузкиФайла();
//   ПараметрыЗагрузки.ИдентификаторФормы = УникальныйИдентификатор;
//   ФайловаяСистемаКлиент.ЗагрузитьФайл(Оповещение, ПараметрыЗагрузки);
//
ФайловаяСистемаКлиент.ЗагрузитьФайл(ОбработчикЗавершения, ПараметрыЗагрузки = Неопределено, ИмяФайла = "",
	АдресВоВременномХранилище = "") Экспорт
```