---
title: Загрузить файлы во временное хранилище
slug: общие-работа-с-файловой-системой/загрузить-файлы-во-временное-хранилище
---
# Описание

```bsl
// Показывает диалог выбора файлов и помещает выбранные файлы во временное хранилище.
// Совмещает работу методов глобального контекста НачатьПомещениеФайла и НачатьПомещениеФайлов,
// возвращая идентичный результат вне зависимости от того, подключено или нет расширение для работы с 1С:Предприятием.
// Ограничения:
//   Не используется для выбора каталогов - эта опция не поддерживается веб-клиентом.
//   Не поддерживается множественный выбор в веб-клиенте, если не установлено расширение для работы с 1С:Предприятием.
//
// Параметры:
//   ОбработчикЗавершения - ОписаниеОповещения - содержит описание процедуры, которая будет вызвана после
//                             загрузки файлов со следующими параметрами:
//      # ПомещенныеФайлы - Неопределено - пользователь отказался от выбора или файл занят другой программой.
//                        - Массив из Структура - пользователь выбрал файл:
//                           ## Хранение  - Строка - адрес временного хранилища с двоичными данными файла.
//                           ## Имя       - Строка - в тонком клиенте и в веб-клиенте с установленным
//                                        расширением работы с 1С:Предприятием - локальный путь, по которому
//                                        был получен файл. В веб-клиенте без расширения для работы с 1С:Предприятием
//                                        передается имя файла с расширением.
//                           ## ПолноеИмя - Строка - в тонком клиенте и в веб-клиенте с установленным
//                                         расширением работы с 1С:Предприятием - локальный путь, по которому
//                                         был получен файл. В веб-клиенте без расширения для работы с 1С:Предприятием
//                                         принимает значение "".
//                           ## ИмяФайла  - Строка - имя файла с расширением.
//      # ДополнительныеПараметры - Произвольный - значение, которое было указано при создании объекта ОписаниеОповещения.
//   ПараметрыЗагрузки    - см. ФайловаяСистемаКлиент.ПараметрыЗагрузкиФайла.
//   ЗагружаемыеФайлы     - Массив - содержит объекты типа ОписаниеПередаваемогоФайла. Может быть заполнен полностью,
//                        в этом случае загружаемые файлы будут сохранены по указанным адресам. Может быть заполнен
//                        частично - у элементов массива заполнены только имена. В этом случае, загружаемые файлы будут
//                        размещены в новых временных хранилищах. Массив может быть не заполнен. В этом случае набор
//                        помещаемых файлов определяется по значениям, указанным в параметре ПараметрыЗагрузки. Если в
//                        параметрах загрузки выбран неинтерактивный режим и параметр ЗагружаемыеФайлы не заполнен,
//                        будет вызвано исключение.
//
// Пример:
//   Оповещение = Новый ОписаниеОповещения("ЗагрузитьРасширениеПослеПомещенияФайлов", ЭтотОбъект, Контекст);
//   ПараметрыЗагрузки = ФайловаяСистемаКлиент.ПараметрыЗагрузкиФайла();
//   ПараметрыЗагрузки.ИдентификаторФормы = УникальныйИдентификатор;
//   ФайловаяСистемаКлиент.ЗагрузитьФайлы(Оповещение, ПараметрыЗагрузки);
//
ФайловаяСистемаКлиент.ЗагрузитьФайлы(ОбработчикЗавершения, ПараметрыЗагрузки = Неопределено, ЗагружаемыеФайлы = Неопределено) Экспорт
	
```